---
permalink: /manual/
fbcontact: true
---

# Benutzerhandbuch

Willkommen beim KMUHelper!

Diese Bedienungsanleitung sollte Ihnen dazu helfen, den KMUHelper zu verstehen und ihn zu benutzen.

PS: Diese Anleitung setzt die [Installation](../installation.md) des KMUHelper voraus.

## Hilfe & Support

Falls Sie irgendwelche Fragen haben, können Sie mich sehr gerne [kontaktieren](<{{ site.kontakt_url }}>).

Die Entwicklung und Unterhaltung des KMUHelper benötigt sehr viel Zeit, deshalb bin ich sehr auf [Unterstützung](../support.md) angewiesen.

## Inhalt

- [Einrichtung](setup.md)
- [App](app.md)

- [Lagermanagement](storage.md)
- [Kundenmanagement](customers.md)
- [Bestellungen & Rechnungen](order-and-invoice.md)

- [Sprachen](languages.md)

Hinweis: Zu Demonstrationszwecken werden in dieser Bedienungsanleitung relative URL oder die Domain `example.com` verwendet. In beiden Fällen sollten Sie diese mit Ihrer Domain ergänzen bzw. ersetzen.
